@@ -2,12 +2,10 @@
 #' @importFrom utils head
 #' @inheritParams head
 head.chunkwise <- function(x, n=6L, ...){
-  if (is.null(n)){
-    n <- 6L
-  }
+  stopifnot(length(n) == 1)
   res <- x$first_chunk(x$cmds)
   while(nrow(res) < n && !x$is_complete()){
     res <- rbind(res, x$next_chunk(x$cmd))
   }
-  utils::head(res)
+  utils::head(res, n=n)
 }
